# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.0
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _medfilter
else:
    import _medfilter

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator_medfilter_module(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _medfilter.delete_SwigPyIterator_medfilter_module

    def value(self):
        return _medfilter.SwigPyIterator_medfilter_module_value(self)

    def incr(self, n=1):
        return _medfilter.SwigPyIterator_medfilter_module_incr(self, n)

    def decr(self, n=1):
        return _medfilter.SwigPyIterator_medfilter_module_decr(self, n)

    def distance(self, x):
        return _medfilter.SwigPyIterator_medfilter_module_distance(self, x)

    def equal(self, x):
        return _medfilter.SwigPyIterator_medfilter_module_equal(self, x)

    def copy(self):
        return _medfilter.SwigPyIterator_medfilter_module_copy(self)

    def next(self):
        return _medfilter.SwigPyIterator_medfilter_module_next(self)

    def __next__(self):
        return _medfilter.SwigPyIterator_medfilter_module___next__(self)

    def previous(self):
        return _medfilter.SwigPyIterator_medfilter_module_previous(self)

    def advance(self, n):
        return _medfilter.SwigPyIterator_medfilter_module_advance(self, n)

    def __eq__(self, x):
        return _medfilter.SwigPyIterator_medfilter_module___eq__(self, x)

    def __ne__(self, x):
        return _medfilter.SwigPyIterator_medfilter_module___ne__(self, x)

    def __iadd__(self, n):
        return _medfilter.SwigPyIterator_medfilter_module___iadd__(self, n)

    def __isub__(self, n):
        return _medfilter.SwigPyIterator_medfilter_module___isub__(self, n)

    def __add__(self, n):
        return _medfilter.SwigPyIterator_medfilter_module___add__(self, n)

    def __sub__(self, *args):
        return _medfilter.SwigPyIterator_medfilter_module___sub__(self, *args)
    def __iter__(self): return self
    def __iter__(self):
        return self

# Register SwigPyIterator_medfilter_module in _medfilter:
_medfilter.SwigPyIterator_medfilter_module_swigregister(SwigPyIterator_medfilter_module)
HAVE_CC_C99 = _medfilter.HAVE_CC_C99
HAVE_CUSERID = _medfilter.HAVE_CUSERID
HAVE_DLFCN_H = _medfilter.HAVE_DLFCN_H
HAVE_FTIME = _medfilter.HAVE_FTIME
HAVE_GETEUID = _medfilter.HAVE_GETEUID
HAVE_GETPWUID = _medfilter.HAVE_GETPWUID
HAVE_GETTIMEOFDAY = _medfilter.HAVE_GETTIMEOFDAY
HAVE_H5PUBLIC_H = _medfilter.HAVE_H5PUBLIC_H
HAVE_INT64 = _medfilter.HAVE_INT64
HAVE_INTTYPES_H = _medfilter.HAVE_INTTYPES_H
HAVE_MALLOC_H = _medfilter.HAVE_MALLOC_H
HAVE_PWD_H = _medfilter.HAVE_PWD_H
HAVE_STDBOOL_H = _medfilter.HAVE_STDBOOL_H
HAVE_STDINT_H = _medfilter.HAVE_STDINT_H
HAVE_STDIO_H = _medfilter.HAVE_STDIO_H
HAVE_STDLIB_H = _medfilter.HAVE_STDLIB_H
HAVE_STRINGS_H = _medfilter.HAVE_STRINGS_H
HAVE_STRING_H = _medfilter.HAVE_STRING_H
HAVE_SYS_STAT_H = _medfilter.HAVE_SYS_STAT_H
HAVE_SYS_TIMEB_H = _medfilter.HAVE_SYS_TIMEB_H
HAVE_SYS_TIME_H = _medfilter.HAVE_SYS_TIME_H
HAVE_SYS_TYPES_H = _medfilter.HAVE_SYS_TYPES_H
HAVE_UNISTD_H = _medfilter.HAVE_UNISTD_H
HAVE__BOOL = _medfilter.HAVE__BOOL
MED_CHECK_23FORMAT = _medfilter.MED_CHECK_23FORMAT
MED_HAVE_FORTRAN = _medfilter.MED_HAVE_FORTRAN
MESGERR = _medfilter.MESGERR
PACKAGE = _medfilter.PACKAGE
PACKAGE_BUGREPORT = _medfilter.PACKAGE_BUGREPORT
PACKAGE_NAME = _medfilter.PACKAGE_NAME
PACKAGE_STRING = _medfilter.PACKAGE_STRING
PACKAGE_URL = _medfilter.PACKAGE_URL
PACKAGE_VERSION = _medfilter.PACKAGE_VERSION
SIZEOF_FORTRAN_INTEGER = _medfilter.SIZEOF_FORTRAN_INTEGER
SIZEOF_INT = _medfilter.SIZEOF_INT
SIZEOF_LONG = _medfilter.SIZEOF_LONG
STDC_HEADERS = _medfilter.STDC_HEADERS
VERSION = _medfilter.VERSION
HDF_VERSION_REF = _medfilter.HDF_VERSION_REF
HDF_VERSION_MAJOR_REF = _medfilter.HDF_VERSION_MAJOR_REF
HDF_VERSION_MINOR_REF = _medfilter.HDF_VERSION_MINOR_REF
HDF_VERSION_RELEASE_REF = _medfilter.HDF_VERSION_RELEASE_REF
HDF_VERSION_NUM_REF = _medfilter.HDF_VERSION_NUM_REF
H5F_LIBVER_18 = _medfilter.H5F_LIBVER_18
MED_MAJOR_NUM = _medfilter.MED_MAJOR_NUM
MED_MINOR_NUM = _medfilter.MED_MINOR_NUM
MED_RELEASE_NUM = _medfilter.MED_RELEASE_NUM
MED_3_LATEST_MINOR = _medfilter.MED_3_LATEST_MINOR
MED_4_LATEST_MINOR = _medfilter.MED_4_LATEST_MINOR
MED_5_LATEST_MINOR = _medfilter.MED_5_LATEST_MINOR
MED_50_LATEST_RELEASE = _medfilter.MED_50_LATEST_RELEASE
MED_NUM_MAJEUR = _medfilter.MED_NUM_MAJEUR
MED_NUM_MINEUR = _medfilter.MED_NUM_MINEUR
MED_NUM_RELEASE = _medfilter.MED_NUM_RELEASE
MED_VERSION_STR = _medfilter.MED_VERSION_STR
MED_MAX_PARA = _medfilter.MED_MAX_PARA
MED_COMMENT_SIZE = _medfilter.MED_COMMENT_SIZE
MED_IDENT_SIZE = _medfilter.MED_IDENT_SIZE
MED_NAME_SIZE = _medfilter.MED_NAME_SIZE
MED_SNAME_SIZE = _medfilter.MED_SNAME_SIZE
MED_LNAME_SIZE = _medfilter.MED_LNAME_SIZE
MED_SNAME_BLANK = _medfilter.MED_SNAME_BLANK
MED_NAME_BLANK = _medfilter.MED_NAME_BLANK
MED_PATHNAME_SIZE = _medfilter.MED_PATHNAME_SIZE
MED_MAX_CHFID_PATH = _medfilter.MED_MAX_CHFID_PATH
MED_FULL_INTERLACE = _medfilter.MED_FULL_INTERLACE
MED_NO_INTERLACE = _medfilter.MED_NO_INTERLACE
MED_UNDEF_INTERLACE = _medfilter.MED_UNDEF_INTERLACE
MED_UNDEF_STMODE = _medfilter.MED_UNDEF_STMODE
MED_GLOBAL_STMODE = _medfilter.MED_GLOBAL_STMODE
MED_COMPACT_STMODE = _medfilter.MED_COMPACT_STMODE
MED_GLOBAL_PFLMODE = _medfilter.MED_GLOBAL_PFLMODE
MED_COMPACT_PFLMODE = _medfilter.MED_COMPACT_PFLMODE
MED_UNDEF_PFLMODE = _medfilter.MED_UNDEF_PFLMODE
MED_ACC_RDONLY = _medfilter.MED_ACC_RDONLY
MED_ACC_RDWR = _medfilter.MED_ACC_RDWR
MED_ACC_RDEXT = _medfilter.MED_ACC_RDEXT
MED_ACC_CREAT = _medfilter.MED_ACC_CREAT
MED_ACC_UNDEF = _medfilter.MED_ACC_UNDEF
MED_UNSTRUCTURED_MESH = _medfilter.MED_UNSTRUCTURED_MESH
MED_STRUCTURED_MESH = _medfilter.MED_STRUCTURED_MESH
MED_UNDEF_MESH_TYPE = _medfilter.MED_UNDEF_MESH_TYPE
MED_CARTESIAN_GRID = _medfilter.MED_CARTESIAN_GRID
MED_POLAR_GRID = _medfilter.MED_POLAR_GRID
MED_CURVILINEAR_GRID = _medfilter.MED_CURVILINEAR_GRID
MED_UNDEF_GRID_TYPE = _medfilter.MED_UNDEF_GRID_TYPE
MED_CELL = _medfilter.MED_CELL
MED_DESCENDING_FACE = _medfilter.MED_DESCENDING_FACE
MED_DESCENDING_EDGE = _medfilter.MED_DESCENDING_EDGE
MED_NODE = _medfilter.MED_NODE
MED_NODE_ELEMENT = _medfilter.MED_NODE_ELEMENT
MED_STRUCT_ELEMENT = _medfilter.MED_STRUCT_ELEMENT
MED_ALL_ENTITY_TYPE = _medfilter.MED_ALL_ENTITY_TYPE
MED_UNDEF_ENTITY_TYPE = _medfilter.MED_UNDEF_ENTITY_TYPE
MED_N_ENTITY_TYPES = _medfilter.MED_N_ENTITY_TYPES
MED_COORDINATE = _medfilter.MED_COORDINATE
MED_CONNECTIVITY = _medfilter.MED_CONNECTIVITY
MED_NAME = _medfilter.MED_NAME
MED_NUMBER = _medfilter.MED_NUMBER
MED_FAMILY_NUMBER = _medfilter.MED_FAMILY_NUMBER
MED_COORDINATE_AXIS1 = _medfilter.MED_COORDINATE_AXIS1
MED_COORDINATE_AXIS2 = _medfilter.MED_COORDINATE_AXIS2
MED_COORDINATE_AXIS3 = _medfilter.MED_COORDINATE_AXIS3
MED_INDEX_FACE = _medfilter.MED_INDEX_FACE
MED_INDEX_NODE = _medfilter.MED_INDEX_NODE
MED_GLOBAL_NUMBER = _medfilter.MED_GLOBAL_NUMBER
MED_VARIABLE_ATTRIBUTE = _medfilter.MED_VARIABLE_ATTRIBUTE
MED_COORDINATE_TRSF = _medfilter.MED_COORDINATE_TRSF
MED_UNDEF_DATATYPE = _medfilter.MED_UNDEF_DATATYPE
MED_INTERNAL_FLOAT32 = _medfilter.MED_INTERNAL_FLOAT32
MED_INTERNAL_FLOAT64 = _medfilter.MED_INTERNAL_FLOAT64
MED_INTERNAL_INT8 = _medfilter.MED_INTERNAL_INT8
MED_INTERNAL_INT32 = _medfilter.MED_INTERNAL_INT32
MED_INTERNAL_INT64 = _medfilter.MED_INTERNAL_INT64
MED_INTERNAL_INT = _medfilter.MED_INTERNAL_INT
MED_INTERNAL_NAME = _medfilter.MED_INTERNAL_NAME
MED_INTERNAL_SNAME = _medfilter.MED_INTERNAL_SNAME
MED_INTERNAL_LNAME = _medfilter.MED_INTERNAL_LNAME
MED_INTERNAL_IDENT = _medfilter.MED_INTERNAL_IDENT
MED_INTERNAL_CHAR = _medfilter.MED_INTERNAL_CHAR
MED_INTERNAL_UNDEF = _medfilter.MED_INTERNAL_UNDEF
MED_DOUBLE = _medfilter.MED_DOUBLE
MED_FLOAT64 = _medfilter.MED_FLOAT64
MED_FLOAT32 = _medfilter.MED_FLOAT32
MED_INT32 = _medfilter.MED_INT32
MED_INT64 = _medfilter.MED_INT64
MED_INT = _medfilter.MED_INT
MED_ATT_FLOAT64 = _medfilter.MED_ATT_FLOAT64
MED_ATT_INT = _medfilter.MED_ATT_INT
MED_ATT_NAME = _medfilter.MED_ATT_NAME
MED_ATT_UNDEF = _medfilter.MED_ATT_UNDEF
MED_MESH = _medfilter.MED_MESH
MED_FIELD = _medfilter.MED_FIELD
MED_LIBRARY = _medfilter.MED_LIBRARY
MED_FILE = _medfilter.MED_FILE
MED_MESH_SUPPORT = _medfilter.MED_MESH_SUPPORT
MED_ELSTRUCT = _medfilter.MED_ELSTRUCT
MED_FAMILY = _medfilter.MED_FAMILY
MED_EQUIVALENCE = _medfilter.MED_EQUIVALENCE
MED_GROUP = _medfilter.MED_GROUP
MED_JOINT = _medfilter.MED_JOINT
MED_LOCALIZATION = _medfilter.MED_LOCALIZATION
MED_PROFILE = _medfilter.MED_PROFILE
MED_FILTER = _medfilter.MED_FILTER
MED_INTERPOLATION = _medfilter.MED_INTERPOLATION
MED_NUMERICAL_DATA = _medfilter.MED_NUMERICAL_DATA
MED_LINK = _medfilter.MED_LINK
MED_CLASS_UNDEF = _medfilter.MED_CLASS_UNDEF
MED_CLASS_ALL = _medfilter.MED_CLASS_ALL
MED_POINT1 = _medfilter.MED_POINT1
MED_SEG2 = _medfilter.MED_SEG2
MED_SEG3 = _medfilter.MED_SEG3
MED_SEG4 = _medfilter.MED_SEG4
MED_TRIA3 = _medfilter.MED_TRIA3
MED_QUAD4 = _medfilter.MED_QUAD4
MED_TRIA6 = _medfilter.MED_TRIA6
MED_TRIA7 = _medfilter.MED_TRIA7
MED_QUAD8 = _medfilter.MED_QUAD8
MED_QUAD9 = _medfilter.MED_QUAD9
MED_TETRA4 = _medfilter.MED_TETRA4
MED_PYRA5 = _medfilter.MED_PYRA5
MED_PENTA6 = _medfilter.MED_PENTA6
MED_HEXA8 = _medfilter.MED_HEXA8
MED_TETRA10 = _medfilter.MED_TETRA10
MED_OCTA12 = _medfilter.MED_OCTA12
MED_PYRA13 = _medfilter.MED_PYRA13
MED_PENTA15 = _medfilter.MED_PENTA15
MED_PENTA18 = _medfilter.MED_PENTA18
MED_HEXA20 = _medfilter.MED_HEXA20
MED_HEXA27 = _medfilter.MED_HEXA27
MED_POLYGON = _medfilter.MED_POLYGON
MED_POLYGON2 = _medfilter.MED_POLYGON2
MED_POLYHEDRON = _medfilter.MED_POLYHEDRON
MED_STRUCT_GEO_INTERNAL = _medfilter.MED_STRUCT_GEO_INTERNAL
MED_STRUCT_GEO_SUP_INTERNAL = _medfilter.MED_STRUCT_GEO_SUP_INTERNAL
MED_NONE = _medfilter.MED_NONE
MED_NO_GEOTYPE = _medfilter.MED_NO_GEOTYPE
MED_UNDEF_GEOTYPE = _medfilter.MED_UNDEF_GEOTYPE
MED_UNDEF_GEOMETRY_TYPE = _medfilter.MED_UNDEF_GEOMETRY_TYPE
MED_ALL_GEOTYPE = _medfilter.MED_ALL_GEOTYPE
MED_GEO_ALL = _medfilter.MED_GEO_ALL
MED_N_CELL_GEO = _medfilter.MED_N_CELL_GEO
MED_N_CELL_FIXED_GEO = _medfilter.MED_N_CELL_FIXED_GEO
MED_N_CELL_GEO_FIXED_CON = _medfilter.MED_N_CELL_GEO_FIXED_CON
MED_N_FACE_GEO = _medfilter.MED_N_FACE_GEO
MED_N_FACE_FIXED_GEO = _medfilter.MED_N_FACE_FIXED_GEO
MED_N_FACE_GEO_FIXED_CON = _medfilter.MED_N_FACE_GEO_FIXED_CON
MED_N_EDGE_TYPES = _medfilter.MED_N_EDGE_TYPES
MED_N_EDGE_FIXED_GEO = _medfilter.MED_N_EDGE_FIXED_GEO
MED_N_EDGE_GEO_FIXED_CON = _medfilter.MED_N_EDGE_GEO_FIXED_CON
MED_N_NODE_GEO = _medfilter.MED_N_NODE_GEO
MED_N_NODE_FIXED_GEO = _medfilter.MED_N_NODE_FIXED_GEO
MED_N_NODE_GEO_FIXED_CON = _medfilter.MED_N_NODE_GEO_FIXED_CON
MED_NODAL = _medfilter.MED_NODAL
MED_DESCENDING = _medfilter.MED_DESCENDING
MED_UNDEF_CONNECTIVITY_MODE = _medfilter.MED_UNDEF_CONNECTIVITY_MODE
MED_NO_CMODE = _medfilter.MED_NO_CMODE
MED_CARTESIAN = _medfilter.MED_CARTESIAN
MED_CYLINDRICAL = _medfilter.MED_CYLINDRICAL
MED_SPHERICAL = _medfilter.MED_SPHERICAL
MED_UNDEF_AXIS_TYPE = _medfilter.MED_UNDEF_AXIS_TYPE
MED_FALSE = _medfilter.MED_FALSE
MED_TRUE = _medfilter.MED_TRUE
MED_GAUSS_ELNO = _medfilter.MED_GAUSS_ELNO
MED_IPOINT_ELNO = _medfilter.MED_IPOINT_ELNO
MED_NO_NAME = _medfilter.MED_NO_NAME
MED_NO_MESHNAME = _medfilter.MED_NO_MESHNAME
MED_NO_MESH = _medfilter.MED_NO_MESH
MED_NO_MESH_SUPPORT = _medfilter.MED_NO_MESH_SUPPORT
MED_NO_LOCALIZATION = _medfilter.MED_NO_LOCALIZATION
MED_NO_INTERPOLATION = _medfilter.MED_NO_INTERPOLATION
MED_NO_IPOINT_INTERNAL = _medfilter.MED_NO_IPOINT_INTERNAL
MED_NO_PROFILE = _medfilter.MED_NO_PROFILE
MED_NO_GROUP = _medfilter.MED_NO_GROUP
MED_ALLENTITIES_PROFILE = _medfilter.MED_ALLENTITIES_PROFILE
MED_NO_PROFILE_INTERNAL = _medfilter.MED_NO_PROFILE_INTERNAL
MED_SAME_PROFILE_INTERNAL = _medfilter.MED_SAME_PROFILE_INTERNAL
MED_ALL_CONSTITUENT = _medfilter.MED_ALL_CONSTITUENT
MED_UNDEF_SIZE = _medfilter.MED_UNDEF_SIZE
MED_NO_PROFILE_SIZE = _medfilter.MED_NO_PROFILE_SIZE
MED_SORT_DTIT = _medfilter.MED_SORT_DTIT
MED_SORT_ITDT = _medfilter.MED_SORT_ITDT
MED_SORT_UNDEF = _medfilter.MED_SORT_UNDEF
MED_ALL_DT = _medfilter.MED_ALL_DT
MED_ALL_IT = _medfilter.MED_ALL_IT
MED_NO_DT = _medfilter.MED_NO_DT
MED_NO_IT = _medfilter.MED_NO_IT
MED_UNDEF_DT = _medfilter.MED_UNDEF_DT
MED_ATT_NOT_FILLED = _medfilter.MED_ATT_NOT_FILLED
MED_MAX_FILTER_SPACES = _medfilter.MED_MAX_FILTER_SPACES
class med_filter(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    nspaces = property(_medfilter.med_filter_nspaces_get, _medfilter.med_filter_nspaces_set)
    memspace = property(_medfilter.med_filter_memspace_get, _medfilter.med_filter_memspace_set)
    diskspace = property(_medfilter.med_filter_diskspace_get, _medfilter.med_filter_diskspace_set)
    nentity = property(_medfilter.med_filter_nentity_get, _medfilter.med_filter_nentity_set)
    nvaluesperentity = property(_medfilter.med_filter_nvaluesperentity_get, _medfilter.med_filter_nvaluesperentity_set)
    nconstituentpervalue = property(_medfilter.med_filter_nconstituentpervalue_get, _medfilter.med_filter_nconstituentpervalue_set)
    constituentselect = property(_medfilter.med_filter_constituentselect_get, _medfilter.med_filter_constituentselect_set)
    switchmode = property(_medfilter.med_filter_switchmode_get, _medfilter.med_filter_switchmode_set)
    filterarraysize = property(_medfilter.med_filter_filterarraysize_get, _medfilter.med_filter_filterarraysize_set)
    filterarray23v30 = property(_medfilter.med_filter_filterarray23v30_get, _medfilter.med_filter_filterarray23v30_set)
    profilearraysize = property(_medfilter.med_filter_profilearraysize_get, _medfilter.med_filter_profilearraysize_set)
    storagemode = property(_medfilter.med_filter_storagemode_get, _medfilter.med_filter_storagemode_set)
    profilename = property(_medfilter.med_filter_profilename_get, _medfilter.med_filter_profilename_set)

    def __init__(self):
        r"""__init__(self) -> med_filter"""
        _medfilter.med_filter_swiginit(self, _medfilter.new_med_filter())
    __swig_destroy__ = _medfilter.delete_med_filter

# Register med_filter in _medfilter:
_medfilter.med_filter_swigregister(med_filter)
MED_NO_FILTER_SIZE = _medfilter.MED_NO_FILTER_SIZE
MED_NO_PROFILE_F = _medfilter.MED_NO_PROFILE_F
class med_file_version(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    majeur = property(_medfilter.med_file_version_majeur_get, _medfilter.med_file_version_majeur_set)
    mineur = property(_medfilter.med_file_version_mineur_get, _medfilter.med_file_version_mineur_set)
    release = property(_medfilter.med_file_version_release_get, _medfilter.med_file_version_release_set)

    def __init__(self):
        r"""__init__(self) -> med_file_version"""
        _medfilter.med_file_version_swiginit(self, _medfilter.new_med_file_version())
    __swig_destroy__ = _medfilter.delete_med_file_version

# Register med_file_version in _medfilter:
_medfilter.med_file_version_swigregister(med_file_version)
class med_memfile(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    app_image_ptr = property(_medfilter.med_memfile_app_image_ptr_get, _medfilter.med_memfile_app_image_ptr_set)
    app_image_size = property(_medfilter.med_memfile_app_image_size_get, _medfilter.med_memfile_app_image_size_set)
    ref_count = property(_medfilter.med_memfile_ref_count_get, _medfilter.med_memfile_ref_count_set)
    fapl_image_ptr = property(_medfilter.med_memfile_fapl_image_ptr_get, _medfilter.med_memfile_fapl_image_ptr_set)
    fapl_image_size = property(_medfilter.med_memfile_fapl_image_size_get, _medfilter.med_memfile_fapl_image_size_set)
    fapl_ref_count = property(_medfilter.med_memfile_fapl_ref_count_get, _medfilter.med_memfile_fapl_ref_count_set)
    vfd_image_ptr = property(_medfilter.med_memfile_vfd_image_ptr_get, _medfilter.med_memfile_vfd_image_ptr_set)
    vfd_image_size = property(_medfilter.med_memfile_vfd_image_size_get, _medfilter.med_memfile_vfd_image_size_set)
    vfd_ref_count = property(_medfilter.med_memfile_vfd_ref_count_get, _medfilter.med_memfile_vfd_ref_count_set)
    flags = property(_medfilter.med_memfile_flags_get, _medfilter.med_memfile_flags_set)

    def __init__(self):
        r"""__init__(self) -> med_memfile"""
        _medfilter.med_memfile_swiginit(self, _medfilter.new_med_memfile())
    __swig_destroy__ = _medfilter.delete_med_memfile

# Register med_memfile in _medfilter:
_medfilter.med_memfile_swigregister(med_memfile)

def MEDgetEntityTypeIt(entitytype):
    return _medfilter.MEDgetEntityTypeIt(entitytype)

def MEDgetCellGeometryTypeIt(geotype):
    return _medfilter.MEDgetCellGeometryTypeIt(geotype)

def MEDgetFaceGeometryTypeIt(geotype):
    return _medfilter.MEDgetFaceGeometryTypeIt(geotype)

def MEDgetEdgeGeometryTypeIt(geotype):
    return _medfilter.MEDgetEdgeGeometryTypeIt(geotype)

def MEDgetNodeGeometryTypeIt(geotype):
    return _medfilter.MEDgetNodeGeometryTypeIt(geotype)

def MEDgetEntityGeometryTypeIt(entitytype, geotype):
    return _medfilter.MEDgetEntityGeometryTypeIt(entitytype, geotype)

def MEDgetGeometryTypeName(geotype):
    return _medfilter.MEDgetGeometryTypeName(geotype)

def MEDgetEntityTypeName(entitytype):
    return _medfilter.MEDgetEntityTypeName(entitytype)
MED_PARTICLE_NAME = _medfilter.MED_PARTICLE_NAME
MED_BALL_NAME = _medfilter.MED_BALL_NAME
MED_BEAM_NAME = _medfilter.MED_BEAM_NAME
MED_PARTICLE_LABEL = _medfilter.MED_PARTICLE_LABEL
MED_BALL_DIAMETER = _medfilter.MED_BALL_DIAMETER
MED_BEAM_THICKNESS = _medfilter.MED_BEAM_THICKNESS
import med.medenum
class MEDBOOL(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medfilter.MEDBOOL_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medfilter.MEDBOOL___nonzero__(self)

    def __bool__(self):
        return _medfilter.MEDBOOL___bool__(self)

    def __len__(self):
        return _medfilter.MEDBOOL___len__(self)

    def __getslice__(self, i, j):
        return _medfilter.MEDBOOL___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medfilter.MEDBOOL___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medfilter.MEDBOOL___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medfilter.MEDBOOL___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medfilter.MEDBOOL___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medfilter.MEDBOOL___setitem__(self, *args)

    def pop(self):
        return _medfilter.MEDBOOL_pop(self)

    def append(self, x):
        return _medfilter.MEDBOOL_append(self, x)

    def empty(self):
        return _medfilter.MEDBOOL_empty(self)

    def size(self):
        return _medfilter.MEDBOOL_size(self)

    def swap(self, v):
        return _medfilter.MEDBOOL_swap(self, v)

    def begin(self):
        return _medfilter.MEDBOOL_begin(self)

    def end(self):
        return _medfilter.MEDBOOL_end(self)

    def rbegin(self):
        return _medfilter.MEDBOOL_rbegin(self)

    def rend(self):
        return _medfilter.MEDBOOL_rend(self)

    def clear(self):
        return _medfilter.MEDBOOL_clear(self)

    def get_allocator(self):
        return _medfilter.MEDBOOL_get_allocator(self)

    def pop_back(self):
        return _medfilter.MEDBOOL_pop_back(self)

    def erase(self, *args):
        return _medfilter.MEDBOOL_erase(self, *args)

    def __init__(self, *args):
        _medfilter.MEDBOOL_swiginit(self, _medfilter.new_MEDBOOL(*args))

    def push_back(self, x):
        return _medfilter.MEDBOOL_push_back(self, x)

    def front(self):
        return _medfilter.MEDBOOL_front(self)

    def back(self):
        return _medfilter.MEDBOOL_back(self)

    def assign(self, n, x):
        return _medfilter.MEDBOOL_assign(self, n, x)

    def resize(self, *args):
        return _medfilter.MEDBOOL_resize(self, *args)

    def insert(self, *args):
        return _medfilter.MEDBOOL_insert(self, *args)

    def reserve(self, n):
        return _medfilter.MEDBOOL_reserve(self, n)

    def capacity(self):
        return _medfilter.MEDBOOL_capacity(self)
    __swig_destroy__ = _medfilter.delete_MEDBOOL

# Register MEDBOOL in _medfilter:
_medfilter.MEDBOOL_swigregister(MEDBOOL)
cvar = _medfilter.cvar
MED_GET_ENTITY_TYPENAME = cvar.MED_GET_ENTITY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPENAME = cvar.MED_GET_CELL_GEOMETRY_TYPENAME
MED_GET_FACE_GEOMETRY_TYPENAME = cvar.MED_GET_FACE_GEOMETRY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPE_FROM_ENTITY_TYPE = cvar.MED_GET_CELL_GEOMETRY_TYPE_FROM_ENTITY_TYPE
MED_GET_N_FIXED_GEO_FOR_ENTITY_TYPE_IT = cvar.MED_GET_N_FIXED_GEO_FOR_ENTITY_TYPE_IT


MEDBOOL.__str__= lambda self: str([x for x in self])
MEDBOOL.__repr__= lambda self: "MEDBOOL("+str([x for x in self])+")"

class MEDFLOAT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medfilter.MEDFLOAT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medfilter.MEDFLOAT___nonzero__(self)

    def __bool__(self):
        return _medfilter.MEDFLOAT___bool__(self)

    def __len__(self):
        return _medfilter.MEDFLOAT___len__(self)

    def __getslice__(self, i, j):
        return _medfilter.MEDFLOAT___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medfilter.MEDFLOAT___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medfilter.MEDFLOAT___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medfilter.MEDFLOAT___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medfilter.MEDFLOAT___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medfilter.MEDFLOAT___setitem__(self, *args)

    def pop(self):
        return _medfilter.MEDFLOAT_pop(self)

    def append(self, x):
        return _medfilter.MEDFLOAT_append(self, x)

    def empty(self):
        return _medfilter.MEDFLOAT_empty(self)

    def size(self):
        return _medfilter.MEDFLOAT_size(self)

    def swap(self, v):
        return _medfilter.MEDFLOAT_swap(self, v)

    def begin(self):
        return _medfilter.MEDFLOAT_begin(self)

    def end(self):
        return _medfilter.MEDFLOAT_end(self)

    def rbegin(self):
        return _medfilter.MEDFLOAT_rbegin(self)

    def rend(self):
        return _medfilter.MEDFLOAT_rend(self)

    def clear(self):
        return _medfilter.MEDFLOAT_clear(self)

    def get_allocator(self):
        return _medfilter.MEDFLOAT_get_allocator(self)

    def pop_back(self):
        return _medfilter.MEDFLOAT_pop_back(self)

    def erase(self, *args):
        return _medfilter.MEDFLOAT_erase(self, *args)

    def __init__(self, *args):
        _medfilter.MEDFLOAT_swiginit(self, _medfilter.new_MEDFLOAT(*args))

    def push_back(self, x):
        return _medfilter.MEDFLOAT_push_back(self, x)

    def front(self):
        return _medfilter.MEDFLOAT_front(self)

    def back(self):
        return _medfilter.MEDFLOAT_back(self)

    def assign(self, n, x):
        return _medfilter.MEDFLOAT_assign(self, n, x)

    def resize(self, *args):
        return _medfilter.MEDFLOAT_resize(self, *args)

    def insert(self, *args):
        return _medfilter.MEDFLOAT_insert(self, *args)

    def reserve(self, n):
        return _medfilter.MEDFLOAT_reserve(self, n)

    def capacity(self):
        return _medfilter.MEDFLOAT_capacity(self)

    def __iadd__(self, value):
        return _medfilter.MEDFLOAT___iadd__(self, value)

    def __add__(self, value):
        return _medfilter.MEDFLOAT___add__(self, value)

    def __isub__(self, value):
        return _medfilter.MEDFLOAT___isub__(self, value)

    def __sub__(self, value):
        return _medfilter.MEDFLOAT___sub__(self, value)

    def __imul__(self, value):
        return _medfilter.MEDFLOAT___imul__(self, value)

    def __mul__(self, value):
        return _medfilter.MEDFLOAT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medfilter.MEDFLOAT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medfilter.MEDFLOAT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medfilter.MEDFLOAT___le__(self, value)

    def __lt__(self, value):
        return _medfilter.MEDFLOAT___lt__(self, value)

    def __gt__(self, value):
        return _medfilter.MEDFLOAT___gt__(self, value)

    def __ge__(self, value):
        return _medfilter.MEDFLOAT___ge__(self, value)

    def __eq__(self, value):
        return _medfilter.MEDFLOAT___eq__(self, value)

    def __ne__(self, value):
        return _medfilter.MEDFLOAT___ne__(self, value)
    __swig_destroy__ = _medfilter.delete_MEDFLOAT

# Register MEDFLOAT in _medfilter:
_medfilter.MEDFLOAT_swigregister(MEDFLOAT)

MEDFLOAT.__str__= lambda self: str([x for x in self])
MEDFLOAT.__repr__= lambda self:"MEDFLOAT" +"("+str([x for x in self])+")"


MEDFLOAT64=MEDFLOAT
MEDDOUBLE=MEDFLOAT

class MEDFLOAT32(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medfilter.MEDFLOAT32_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medfilter.MEDFLOAT32___nonzero__(self)

    def __bool__(self):
        return _medfilter.MEDFLOAT32___bool__(self)

    def __len__(self):
        return _medfilter.MEDFLOAT32___len__(self)

    def __getslice__(self, i, j):
        return _medfilter.MEDFLOAT32___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medfilter.MEDFLOAT32___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medfilter.MEDFLOAT32___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medfilter.MEDFLOAT32___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medfilter.MEDFLOAT32___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medfilter.MEDFLOAT32___setitem__(self, *args)

    def pop(self):
        return _medfilter.MEDFLOAT32_pop(self)

    def append(self, x):
        return _medfilter.MEDFLOAT32_append(self, x)

    def empty(self):
        return _medfilter.MEDFLOAT32_empty(self)

    def size(self):
        return _medfilter.MEDFLOAT32_size(self)

    def swap(self, v):
        return _medfilter.MEDFLOAT32_swap(self, v)

    def begin(self):
        return _medfilter.MEDFLOAT32_begin(self)

    def end(self):
        return _medfilter.MEDFLOAT32_end(self)

    def rbegin(self):
        return _medfilter.MEDFLOAT32_rbegin(self)

    def rend(self):
        return _medfilter.MEDFLOAT32_rend(self)

    def clear(self):
        return _medfilter.MEDFLOAT32_clear(self)

    def get_allocator(self):
        return _medfilter.MEDFLOAT32_get_allocator(self)

    def pop_back(self):
        return _medfilter.MEDFLOAT32_pop_back(self)

    def erase(self, *args):
        return _medfilter.MEDFLOAT32_erase(self, *args)

    def __init__(self, *args):
        _medfilter.MEDFLOAT32_swiginit(self, _medfilter.new_MEDFLOAT32(*args))

    def push_back(self, x):
        return _medfilter.MEDFLOAT32_push_back(self, x)

    def front(self):
        return _medfilter.MEDFLOAT32_front(self)

    def back(self):
        return _medfilter.MEDFLOAT32_back(self)

    def assign(self, n, x):
        return _medfilter.MEDFLOAT32_assign(self, n, x)

    def resize(self, *args):
        return _medfilter.MEDFLOAT32_resize(self, *args)

    def insert(self, *args):
        return _medfilter.MEDFLOAT32_insert(self, *args)

    def reserve(self, n):
        return _medfilter.MEDFLOAT32_reserve(self, n)

    def capacity(self):
        return _medfilter.MEDFLOAT32_capacity(self)

    def __iadd__(self, value):
        return _medfilter.MEDFLOAT32___iadd__(self, value)

    def __add__(self, value):
        return _medfilter.MEDFLOAT32___add__(self, value)

    def __isub__(self, value):
        return _medfilter.MEDFLOAT32___isub__(self, value)

    def __sub__(self, value):
        return _medfilter.MEDFLOAT32___sub__(self, value)

    def __imul__(self, value):
        return _medfilter.MEDFLOAT32___imul__(self, value)

    def __mul__(self, value):
        return _medfilter.MEDFLOAT32___mul__(self, value)

    def __itruediv__(self, *args):
        return _medfilter.MEDFLOAT32___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medfilter.MEDFLOAT32___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medfilter.MEDFLOAT32___le__(self, value)

    def __lt__(self, value):
        return _medfilter.MEDFLOAT32___lt__(self, value)

    def __gt__(self, value):
        return _medfilter.MEDFLOAT32___gt__(self, value)

    def __ge__(self, value):
        return _medfilter.MEDFLOAT32___ge__(self, value)

    def __eq__(self, value):
        return _medfilter.MEDFLOAT32___eq__(self, value)

    def __ne__(self, value):
        return _medfilter.MEDFLOAT32___ne__(self, value)
    __swig_destroy__ = _medfilter.delete_MEDFLOAT32

# Register MEDFLOAT32 in _medfilter:
_medfilter.MEDFLOAT32_swigregister(MEDFLOAT32)

MEDFLOAT32.__str__= lambda self: str([x for x in self])
MEDFLOAT32.__repr__= lambda self:"MEDFLOAT32" +"("+str([x for x in self])+")"

class MEDINT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medfilter.MEDINT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medfilter.MEDINT___nonzero__(self)

    def __bool__(self):
        return _medfilter.MEDINT___bool__(self)

    def __len__(self):
        return _medfilter.MEDINT___len__(self)

    def __getslice__(self, i, j):
        return _medfilter.MEDINT___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medfilter.MEDINT___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medfilter.MEDINT___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medfilter.MEDINT___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medfilter.MEDINT___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medfilter.MEDINT___setitem__(self, *args)

    def pop(self):
        return _medfilter.MEDINT_pop(self)

    def append(self, x):
        return _medfilter.MEDINT_append(self, x)

    def empty(self):
        return _medfilter.MEDINT_empty(self)

    def size(self):
        return _medfilter.MEDINT_size(self)

    def swap(self, v):
        return _medfilter.MEDINT_swap(self, v)

    def begin(self):
        return _medfilter.MEDINT_begin(self)

    def end(self):
        return _medfilter.MEDINT_end(self)

    def rbegin(self):
        return _medfilter.MEDINT_rbegin(self)

    def rend(self):
        return _medfilter.MEDINT_rend(self)

    def clear(self):
        return _medfilter.MEDINT_clear(self)

    def get_allocator(self):
        return _medfilter.MEDINT_get_allocator(self)

    def pop_back(self):
        return _medfilter.MEDINT_pop_back(self)

    def erase(self, *args):
        return _medfilter.MEDINT_erase(self, *args)

    def __init__(self, *args):
        _medfilter.MEDINT_swiginit(self, _medfilter.new_MEDINT(*args))

    def push_back(self, x):
        return _medfilter.MEDINT_push_back(self, x)

    def front(self):
        return _medfilter.MEDINT_front(self)

    def back(self):
        return _medfilter.MEDINT_back(self)

    def assign(self, n, x):
        return _medfilter.MEDINT_assign(self, n, x)

    def resize(self, *args):
        return _medfilter.MEDINT_resize(self, *args)

    def insert(self, *args):
        return _medfilter.MEDINT_insert(self, *args)

    def reserve(self, n):
        return _medfilter.MEDINT_reserve(self, n)

    def capacity(self):
        return _medfilter.MEDINT_capacity(self)

    def __iadd__(self, value):
        return _medfilter.MEDINT___iadd__(self, value)

    def __add__(self, value):
        return _medfilter.MEDINT___add__(self, value)

    def __isub__(self, value):
        return _medfilter.MEDINT___isub__(self, value)

    def __sub__(self, value):
        return _medfilter.MEDINT___sub__(self, value)

    def __imul__(self, value):
        return _medfilter.MEDINT___imul__(self, value)

    def __mul__(self, value):
        return _medfilter.MEDINT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medfilter.MEDINT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medfilter.MEDINT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medfilter.MEDINT___le__(self, value)

    def __lt__(self, value):
        return _medfilter.MEDINT___lt__(self, value)

    def __gt__(self, value):
        return _medfilter.MEDINT___gt__(self, value)

    def __ge__(self, value):
        return _medfilter.MEDINT___ge__(self, value)

    def __eq__(self, value):
        return _medfilter.MEDINT___eq__(self, value)

    def __ne__(self, value):
        return _medfilter.MEDINT___ne__(self, value)
    __swig_destroy__ = _medfilter.delete_MEDINT

# Register MEDINT in _medfilter:
_medfilter.MEDINT_swigregister(MEDINT)

MEDINT.__str__= lambda self: str([x for x in self])
MEDINT.__repr__= lambda self:"MEDINT" +"("+str([x for x in self])+")"


MEDINT32=MEDINT


MEDINT64=None

class MEDCHAR(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medfilter.MEDCHAR_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medfilter.MEDCHAR___nonzero__(self)

    def __bool__(self):
        return _medfilter.MEDCHAR___bool__(self)

    def __len__(self):
        return _medfilter.MEDCHAR___len__(self)

    def __getslice__(self, i, j):
        return _medfilter.MEDCHAR___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medfilter.MEDCHAR___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medfilter.MEDCHAR___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medfilter.MEDCHAR___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medfilter.MEDCHAR___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medfilter.MEDCHAR___setitem__(self, *args)

    def pop(self):
        return _medfilter.MEDCHAR_pop(self)

    def append(self, x):
        return _medfilter.MEDCHAR_append(self, x)

    def empty(self):
        return _medfilter.MEDCHAR_empty(self)

    def size(self):
        return _medfilter.MEDCHAR_size(self)

    def swap(self, v):
        return _medfilter.MEDCHAR_swap(self, v)

    def begin(self):
        return _medfilter.MEDCHAR_begin(self)

    def end(self):
        return _medfilter.MEDCHAR_end(self)

    def rbegin(self):
        return _medfilter.MEDCHAR_rbegin(self)

    def rend(self):
        return _medfilter.MEDCHAR_rend(self)

    def clear(self):
        return _medfilter.MEDCHAR_clear(self)

    def get_allocator(self):
        return _medfilter.MEDCHAR_get_allocator(self)

    def pop_back(self):
        return _medfilter.MEDCHAR_pop_back(self)

    def erase(self, *args):
        return _medfilter.MEDCHAR_erase(self, *args)

    def __init__(self, *args):
        _medfilter.MEDCHAR_swiginit(self, _medfilter.new_MEDCHAR(*args))

    def push_back(self, x):
        return _medfilter.MEDCHAR_push_back(self, x)

    def front(self):
        return _medfilter.MEDCHAR_front(self)

    def back(self):
        return _medfilter.MEDCHAR_back(self)

    def assign(self, n, x):
        return _medfilter.MEDCHAR_assign(self, n, x)

    def resize(self, *args):
        return _medfilter.MEDCHAR_resize(self, *args)

    def insert(self, *args):
        return _medfilter.MEDCHAR_insert(self, *args)

    def reserve(self, n):
        return _medfilter.MEDCHAR_reserve(self, n)

    def capacity(self):
        return _medfilter.MEDCHAR_capacity(self)

    def __iadd__(self, value):
        return _medfilter.MEDCHAR___iadd__(self, value)

    def __add__(self, value):
        return _medfilter.MEDCHAR___add__(self, value)

    def __isub__(self, value):
        return _medfilter.MEDCHAR___isub__(self, value)

    def __sub__(self, value):
        return _medfilter.MEDCHAR___sub__(self, value)

    def __imul__(self, value):
        return _medfilter.MEDCHAR___imul__(self, value)

    def __mul__(self, value):
        return _medfilter.MEDCHAR___mul__(self, value)

    def __itruediv__(self, *args):
        return _medfilter.MEDCHAR___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medfilter.MEDCHAR___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medfilter.MEDCHAR___le__(self, value)

    def __lt__(self, value):
        return _medfilter.MEDCHAR___lt__(self, value)

    def __gt__(self, value):
        return _medfilter.MEDCHAR___gt__(self, value)

    def __ge__(self, value):
        return _medfilter.MEDCHAR___ge__(self, value)

    def __eq__(self, value):
        return _medfilter.MEDCHAR___eq__(self, value)

    def __ne__(self, value):
        return _medfilter.MEDCHAR___ne__(self, value)
    __swig_destroy__ = _medfilter.delete_MEDCHAR

# Register MEDCHAR in _medfilter:
_medfilter.MEDCHAR_swigregister(MEDCHAR)

MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


def MEDfilterEntityCr(fid, nentity, nvaluesperentity, nconstituentpervalue, constituentselect, switchmode, storagemode, profilename, filterarraysize, filterarray, filter):
    r"""
    MEDfilterEntityCr(fid, nentity, nvaluesperentity, nconstituentpervalue, constituentselect, switchmode, storagemode, profilename, filterarraysize, filterarray, filter) -> med_err

    Parameters
    ----------
    fid: med_idt const
    nentity: med_int const
    nvaluesperentity: med_int const
    nconstituentpervalue: med_int const
    constituentselect: med_int const
    switchmode: enum med_switch_mode const
    storagemode: enum med_storage_mode const
    profilename: char const *const
    filterarraysize: med_int const
    filterarray: med_int const *const
    filter: med_filter *const

    """
    return _medfilter.MEDfilterEntityCr(fid, nentity, nvaluesperentity, nconstituentpervalue, constituentselect, switchmode, storagemode, profilename, filterarraysize, filterarray, filter)

def MEDfilterBlockOfEntityCr(fid, nentity, nvaluesperentity, nconstituentpervalue, constituentselect, switchmode, storagemode, profilename, start, stride, count, blocksize, lastblocksize, filter):
    r"""
    MEDfilterBlockOfEntityCr(fid, nentity, nvaluesperentity, nconstituentpervalue, constituentselect, switchmode, storagemode, profilename, start, stride, count, blocksize, lastblocksize, filter) -> med_err

    Parameters
    ----------
    fid: med_idt const
    nentity: med_int const
    nvaluesperentity: med_int const
    nconstituentpervalue: med_int const
    constituentselect: med_int const
    switchmode: enum med_switch_mode const
    storagemode: enum med_storage_mode const
    profilename: char const *const
    start: med_size const
    stride: med_size const
    count: med_size const
    blocksize: med_size const
    lastblocksize: med_size const
    filter: med_filter *const

    """
    return _medfilter.MEDfilterBlockOfEntityCr(fid, nentity, nvaluesperentity, nconstituentpervalue, constituentselect, switchmode, storagemode, profilename, start, stride, count, blocksize, lastblocksize, filter)

def MEDfilterClose(filter):
    r"""
    MEDfilterClose(filter) -> med_err

    Parameters
    ----------
    filter: med_filter *const

    """
    return _medfilter.MEDfilterClose(filter)

